@@ -72,7 +72,7 @@ class Auth():
     def ask(self, key, defaultValue, isMust, isSave, isPass):
         tip = '%s%s: ' % (self.tip[key], '(%s)' % defaultValue if defaultValue else '')
         value = getpass(tip) if isPass else input(tip)
-        if value is '':
+        if value == '':
             if defaultValue:
                 value = defaultValue
             elif isMust:
@@ -80,11 +80,11 @@ class Auth():
                 return self.ask(key, defaultValue, isMust, isSave)
         if isSave:
             # isPass则存储密文, 否则存储明文
-            tarVal = isPass ? aesCbcEncrypt(value, cryptoKey) : value
-            cmd = 'echo %s=%s >> %s' % (key, tarVal, self.envPath)
+            tarVal = aesCbcEncrypt(value, cryptoKey) if isPass else value
+            cmd = 'echo %s=%s >> %s' % (key, tarVal.decode(), self.envPath)
             os.system(cmd)
         return value
-    
+
     def getParams(self):
         return self.val
 
@@ -92,3 +92,4 @@ class Auth():
 if __name__ == '__main__':
     auth = Auth()
     auth.addParams('user', '哈哈')
+
